@@ -1,7 +1,7 @@
 /*
  * src/manager.c - GNOME Volume Manager
  *
- * Robert Love <rml@ximian.com>
+ * Robert Love <rml@novell.com>
  *
  * gnome-volume-manager is a simple policy engine that implements a state
  * machine in response to events from HAL.  Responding to these events,
@@ -227,16 +227,15 @@ gvm_ask_autorun (const char *path)
 					0, GTK_MESSAGE_WARNING,
 					GTK_BUTTONS_NONE,
 					_("Run command from inserted media?"));
-	/*FIXME!! A better secondary label....*/
-	gtk_message_dialog_format_secondary_text (GTK_DIALOG (askme),
-			_("The file \"%s\" on the inserted media is an auto-run"
-			  "file."));
-
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (askme),
+						  "%s", _("Do you want to run "
+						  "the file \"%s?\""));
 	gtk_dialog_add_buttons (GTK_DIALOG (askme),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
 				_("_Run Command"), GTK_RESPONSE_ACCEPT,
 				NULL);
-	gtk_dialog_set_default_response (GTK_DIALOG (askme), GTK_RESPONSE_ACCEPT);
+	gtk_dialog_set_default_response (GTK_DIALOG (askme),
+					 GTK_RESPONSE_ACCEPT);
 
 	switch (gtk_dialog_run (GTK_DIALOG (askme))) {
 	case GTK_RESPONSE_ACCEPT:
@@ -317,10 +316,11 @@ gvm_check_photos (const char *udi, const char *device, const char *mount_point)
 		askme = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_WARNING,
 						GTK_BUTTONS_NONE,
 						_("Import photos from device?"));
-		gtk_message_dialog_format_secondary_text (GTK_DIALOG (askme),
-							  _("There are photos on the inserted media. "
-							    "Would you like to import these "
-							    "photos into your photo album?"));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (askme),
+				"%s",
+				_("There are photos on the inserted media. "
+				  "Would you like to import these photographs "
+				  "into your album?"));
 
 		gtk_dialog_add_buttons (GTK_DIALOG (askme),
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -364,10 +364,11 @@ gvm_check_camera (const char *udi)
 		askme = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_WARNING,
 						GTK_BUTTONS_NONE,
 						_("Import photos from camera?"));
-		gtk_message_dialog_format_secondary_text (GTK_DIALOG (askme),
-							  _("There are photos on the plugged-in camera. "
-							    "Would you like to import these "
-							    "photos into your photo album?"));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (askme),
+				"%s",
+				_("There are photos on the plugged-in camera. "
+				  "Would you like to import these "
+				  "photographss into your album?"));
 		gtk_dialog_add_buttons (GTK_DIALOG (askme),
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					_("_Import Photos"), IMPORT,
@@ -555,12 +556,13 @@ gvm_ask_mixed (const char *udi)
 						GTK_BUTTONS_NONE,
 						_("Browse files or play tracks from disc?"));
 
-		gtk_message_dialog_format_secondary_text (GTK_DIALOG (askme),
-							  _("There are both audio tracks and "
-							    "data files on the inserted disc. "
-							    "Choose if you want to play the audio "
-							    "tracks to listen to music or browse "
-							    "the files to manage the stored data."));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (askme),
+				"%s",
+				_("There are both audio tracks and "
+				  "data files on the inserted disc. "
+				  "Choose if you want to play the audio "
+				  "tracks to listen to music or browse the "
+				  "files to manage the stored data."));
 		gtk_dialog_add_buttons (GTK_DIALOG (askme),
 					_("_Browse Files"), MOUNT,
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -678,8 +680,7 @@ out:
  * At the moment, we only handle CD-ROM and DVD drives.
  */
 static void
-gvm_media_changed (const char *udi, const char *storage_device, 
-		   const char *device)
+gvm_media_changed (const char *udi, const char *storage_device, char *device)
 {
 	char *media_type;
 
@@ -821,6 +822,12 @@ hal_device_lost_capability (LibHalContext *ctx __attribute__((__unused__)),
 {
 }
 
+static gint
+compare_func (const void *a, const void *b)
+{
+	return g_ascii_strcasecmp (a, b);
+}
+
 /** Invoked when a property of a device in the Global Device List is
  *  changed, and we have we have subscribed to changes for that device.
  *
@@ -841,7 +848,7 @@ hal_property_modified (LibHalContext *ctx __attribute__((__unused__)),
 
 	if (g_strcasecmp (key, "volume.is_mounted") != 0)
 		return;
-	
+
 	val = hal_device_get_property_bool (hal_ctx, udi, key);
 	if (val == TRUE) {
 		GSList *policy_udi;
@@ -854,7 +861,7 @@ hal_property_modified (LibHalContext *ctx __attribute__((__unused__)),
 
 		policy_udi = g_slist_find_custom (mounted_volumes_policy_queue, 
 						  udi, 
-						  g_ascii_strcasecmp);
+						  compare_func);
 		if (policy_udi != NULL) {
 			g_free (policy_udi->data);
 			mounted_volumes_policy_queue = g_slist_delete_link (mounted_volumes_policy_queue, 
